libdecor Headers for Rust
This library contains minimalist Rust FFI bindings for libdecor in a way that’s roughly equivalent to the official libdecor.h for C/C++. It makes no attempt at providing safe or idiomatic Rust wrappers and doesn’t rename any C identifiers to match Rust’s style guidelines.
The following Rust code:
use libdecor_headers::libdecor::*;is roughly equivalent to the following C code:
#include <libdecor.h>This library is based specifically on libdecor 0.2.2 since that’s the version provided by Steam Runtime 3 ‘sniper’.
Using this library does not automatically link against libdecor-0.so.